/*******************************************************************************
*                                                                              *
*                                   Viewmol                                    *
*                                                                              *
*                            F A L L B A C K S . H                             *
*                                                                              *
*                 Copyright (c) Joerg-R. Hill, October 2003                    *
*                                                                              *
********************************************************************************
*
* $Id: fallbacks.h,v 1.7 2004/08/29 14:50:37 jrh Exp $
* $Log: fallbacks.h,v $
* Revision 1.7  2004/08/29 14:50:37  jrh
* Release 2.4.1
*
* Revision 1.6  2003/11/07 12:48:48  jrh
* Release 2.4
*
* Revision 1.5  2000/12/10 15:06:57  jrh
* Release 2.3
*
* Revision 1.4  1999/05/24 01:25:24  jrh
* Release 2.2.1
*
* Revision 1.3  1999/02/07 21:48:55  jrh
* Release 2.2
*
* Revision 1.2  1998/01/26 00:47:41  jrh
* Release 2.1
*
* Revision 1.1  1996/12/10  18:45:31  jrh
* Initial revision
*
*/
static String fallbacks[] = {
  "Viewmol.webBrowser:                              mozilla %s",
  "Viewmol.Moloch:                                  moloch",
  "Viewmol.Raytracer:                               x-povray +I%s +O%s +W%d +H%d",
  "Viewmol.DisplayImage:                            xv %s",
/* the following three resources are necessary to get
   the Indigo Magic Desktop look-and-feel */
  "Viewmol*sgiMode:                                 True",
  "Viewmol*useSchemes:                              all",
  "Viewmol*SgNuseEnhancedFSB:                       True",
/* end of SGI specfic stuff */
  "Viewmol.geometry:                                500x500+50+50",
  "Viewmol.history.geometry:                        500x250+50+590",
  "Viewmol.spectrum.geometry:                       500x250+50+590",
  "Viewmol.MODiagram.geometry:                      250x500+565+50",
  "Viewmol.model:                                   wire",
  "Viewmol.drawingMode:                             surface",
  "Viewmol.bondType:                                conjugated",
  "Viewmol.sphereResolution:                        20",
  "Viewmol.lineWidth:                               0",
  "Viewmol.simplifyWhileRotating:                   False",
  "Viewmol.interpolation:                           linear",
  "Viewmol.bondLength:                              %7.4f Ang",
  "Viewmol.bondAngle:                               %7.2f deg",
  "Viewmol.torsionAngle:                            %7.2f deg",
  "Viewmol.wavenumbers:                             0:5000",
  "Viewmol.isosurface:                              0.05",
  "Viewmol.densityResolution:                       0.01",
  "Viewmol.reservedColors:                          0",
  "Viewmol.hydrogenBondThreshold:                   2.0",
  "Viewmol.automaticRecalculation:                  False",
  "Viewmol.thermoUnits:                             joules",
  "Viewmol*spectrumForm*amplitudeSlider.decimalPoints: 2",
  "Viewmol*spectrumForm*amplitudeSlider.minimum:    -250",
  "Viewmol*spectrumForm*amplitudeSlider.maximum:    250",
  "Viewmol*spectrumForm*scaleSlider.decimalPoints:  2",
  "Viewmol*spectrumForm*scaleSlider.minimum:        50",
  "Viewmol*spectrumForm*scaleSlider.maximum:        150",
  "Viewmol*thermoForm*pressureSlider.decimalPoints: 2",
  "Viewmol*thermoForm*pressureSlider.minimum:       1",
  "Viewmol*thermoForm*pressureSlider.maximum:       1000",
  "Viewmol*wavefunctionForm*level.decimalPoints:    3",
  "Viewmol*wavefunctionForm*level.minimum:          1",
  "Viewmol*wavefunctionForm*level.maximum:          100",
  "Viewmol*wavefunctionForm*grid.minimum:           4",
  "Viewmol*wavefunctionForm*grid.maximum:           40",
  "Viewmol*wavefunctionForm*grid.value:             20",
  "Viewmol*MODiagramForm*resolution.minimum:        1",
  "Viewmol*MODiagramForm*resolution.maximum:        1000",
  "Viewmol*MODiagramForm*resolution.decimalPoints:  3",
  "Viewmol*unitcellForm*avalue.minimum:             10",
  "Viewmol*unitcellForm*avalue.maximum:             50",
  "Viewmol*unitcellForm*avalue.decimalPoints:       1",
  "Viewmol*unitcellForm*bvalue.minimum:             10",
  "Viewmol*unitcellForm*bvalue.maximum:             50",
  "Viewmol*unitcellForm*bvalue.decimalPoints:       1",
  "Viewmol*unitcellForm*cvalue.minimum:             10",
  "Viewmol*unitcellForm*cvalue.maximum:             50",
  "Viewmol*unitcellForm*cvalue.decimalPoints:       1",
  "Viewmol*unitcellForm*hvalue.minimum:             -5",
  "Viewmol*unitcellForm*hvalue.maximum:             5",
  "Viewmol*unitcellForm*kvalue.minimum:             -5",
  "Viewmol*unitcellForm*kvalue.maximum:             5",
  "Viewmol*unitcellForm*lvalue.minimum:             -5",
  "Viewmol*unitcellForm*lvalue.maximum:             5",
  "Viewmol*bondForm*thresholdSlider.minimum:        100",
  "Viewmol*bondForm*thresholdSlider.maximum:        250",
  "Viewmol*bondForm*thresholdSlider.decimalPoints:  2",
  "Viewmol*bondForm*scaleRadius.minimum:            1",
  "Viewmol*bondForm*scaleRadius.maximum:            200",
  "Viewmol*bondForm*scaleRadius.decimalPoints:      2",
  "Viewmol*infoForm*text*rows:                      6",
  "Viewmol*infoForm*text*columns:                   80",
  "Viewmol*annotation.highlightThickness:           0",
  "Viewmol.paperSize:                               A4",
  "Viewmol.elementSortOrder:                        C,H,N,O,S",
  "Viewmol.viewer.font:                             variable",
  "Viewmol.spectrum.spectrum.font:                  variable",
  "Viewmol.history.history.font:                    variable",
  "Viewmol.MODiagram.MODiagram.font:                variable",
  "Viewmol.MODiagram.MODiagram.greekFont:           -adobe-symbol-medium-r-normal--14-*",
  "Viewmol.viewer.delay:                            0",
  "Viewmol.viewer.background:                       white",
  "Viewmol.viewer.foreground:                       gray75",
  "Viewmol.spectrum.spectrum.background:            white",
  "Viewmol.spectrum.spectrum.foreground:            black",
  "Viewmol.history.history.background:              white",
  "Viewmol.history.history.foreground:              blue",
  "Viewmol.MODiagram.MODiagram.background:          white",
  "Viewmol.MODiagram.MODiagram.foreground:          black",
  "Viewmol*foreground:                              black",
  "Viewmol.hasLZW:                                  False",
  "Viewmol.language:                                en_US",
  "Viewmol.title:                                   Viewmol",
  "Viewmol.by:                                      by",
  "Viewmol.version:                                 Version",
  "Viewmol.history.title:                           Optimization History (%s)",
  "Viewmol.spectrum.title:                          Spectrum (%s)",
  "Viewmol.spectrum.title1:                         All modes (%s)",
  "Viewmol.spectrum.title2:                         IR spectrum (%s)",
  "Viewmol.spectrum.title3:                         Raman spectrum (%s)",
  "Viewmol.spectrum.title4:                         INS spectrum (%s)",
  "Viewmol.MODiagram.title:                         Energy level diagram (%s)",
  "Viewmol*_popup.molecule.labelString:             Molecule",
  "Viewmol*loadMolecule.labelString:                Load molecule ...",
  "Viewmol*saveMolecule.labelString:                Save molecule ...",
  "Viewmol*saveSelected.labelString:                Save selected atoms ...",
  "Viewmol*deleteMolecule.labelString:              Delete molecule",
  "Viewmol*newMolecule.labelString:                 New molecule ...",
  "Viewmol*buildMolecule.labelString:               Modify molecule ...",
  "Viewmol*_popup.wire_model.labelString:           Wire model",
  "Viewmol*_popup.wire_model.mnemonic:              W",
  "Viewmol*_popup.wire_model.accelerator:           Meta<Key>W",
  "Viewmol*_popup.stick_model.labelString:          Stick model",
  "Viewmol*_popup.stick_model.mnemonic:             t",
  "Viewmol*_popup.stick_model.accelerator:          Meta<Key>T",
  "Viewmol*_popup.ball_and_stick_model.labelString: Ball and stick model",
  "Viewmol*_popup.ball_and_stick_model.mnemonic:    a",
  "Viewmol*_popup.ball_and_stick_model.accelerator: Meta<Key>A",
  "Viewmol*_popup.cpk_model.labelString:            CPK model",
  "Viewmol*_popup.cpk_model.mnemonic:               C",
  "Viewmol*_popup.cpk_model.accelerator:            Meta<Key>C",
  "Viewmol*pseForm_popup*title:                     Modify molecule",
  "Viewmol*change.labelString:                      Change geometry",
  "Viewmol*add.labelString:                         Add atom",
  "Viewmol*delete.labelString:                      Delete atom",
  "Viewmol*replace.labelString:                     Replace atom",
  "Viewmol*create.labelString:                      Create bond",
  "Viewmol*remove.labelString:                      Remove bond",
  "Viewmol*order.labelString:                       Change bond order",
  "Viewmol*torsionDefault.labelString:              Torsion angles default to",
  "Viewmol*trans.labelString:                       trans",
  "Viewmol*cis.labelString:                         cis",
  "Viewmol*gauche.labelString:                      gauche",
  "Viewmol*-gauche.labelString:                     -gauche",
  "Viewmol*bondOrderLabel.labelString:              Bonds are",
  "Viewmol*pseForm_popup*fractional.labelString:    Van der Waals",
  "Viewmol*pseForm_popup*single.labelString:        single",
  "Viewmol*pseForm_popup*double.labelString:        double",
  "Viewmol*pseForm_popup*triple.labelString:        triple",
  "Viewmol*localGeometry.labelString:               Deleting atoms changes local geometry",
  "Viewmol*_popup.geometry_menu.labelString:        Geometry ...",
  "Viewmol*clear_all.labelString:                   Clear all",
  "Viewmol*clear_all.accelerator:                   Ctrl<Key>A",
  "Viewmol*clear_all.acceleratorText:               Ctrl+A",
  "Viewmol*clear_last.labelString:                  Clear last",
  "Viewmol*clear_last.accelerator:                  Ctrl<Key>L",
  "Viewmol*clear_last.acceleratorText:              Ctrl+L",
  "Viewmol*undo.labelString:                        Undo geometry change",
  "Viewmol*undo.accelerator:                        Ctrl<Key>U",
  "Viewmol*undo.acceleratorText:                    Ctrl+U",
  "Viewmol*bondForm_popup.title:                    Bonds",
  "Viewmol*_popup.bondType_menu.labelString:        Bonds ...",
  "Viewmol*bondForm*single.labelString:             single only",
  "Viewmol*bondForm*multiple.labelString:           multiple",
  "Viewmol*bondForm*conjugated.labelString:         conjugated",
  "Viewmol*bondForm*select.labelString:             Scale radius for",
  "Viewmol*bondForm*all.labelString:                all",
  "Viewmol*bondForm*atoms.labelString:              atoms by",
  "Viewmol*showHydrogenBonds.labelString:           Show hydrogen bonds",
  "Viewmol*HydrogenBondLabel.labelString:           Threshold for hydrogen bonds [Ang]",
  "Viewmol*_popup.wave_function.labelString:        Wave function ...",
  "Viewmol*_popup.wave_function.mnemonic:           v",
  "Viewmol*_popup.wave_function.accelerator:        Meta<Key>V",
  "Viewmol*_popup.energy_level_diagram.labelString: Energy level diagram",
  "Viewmol*_popup.energy_level_diagram.mnemonic:    E",
  "Viewmol*_popup.energy_level_diagram.accelerator: Meta<Key>E",
  "Viewmol*_popup.optimization_history.labelString: Optimization history",
  "Viewmol*_popup.optimization_history.mnemonic:    O",
  "Viewmol*_popup.optimization_history.accelerator: Meta<Key>O",
  "Viewmol*_popup.show_forces.labelString:          Show forces",
  "Viewmol*_popup.show_forces.mnemonic:             f",
  "Viewmol*_popup.show_forces.accelerator:          Meta<Key>F",
  "Viewmol*_popup.spectrum.labelString:             Spectrum",
  "Viewmol*_popup.spectrum.mnemonic:                S",
  "Viewmol*_popup.spectrum.accelerator:             Meta<Key>S",
  "Viewmol*_popup.thermodynamics.labelString:       Thermodynamics",
  "Viewmol*_popup.thermodynamics.mnemonic:          y",
  "Viewmol*_popup.thermodynamics.accelerator:       Meta<Key>Y",
  "Viewmol*_popup.show_unit_cell.labelString:       Unit cell ...",
  "Viewmol*_popup.show_unit_cell.mnemonic:          n",
  "Viewmol*_popup.show_unit_cell.accelerator:       Meta<Key>N",
  "Viewmol*_popup.show_ellipsoid_of_inertia.labelString: Show ellipsoid of inertia",
  "Viewmol*_popup.show_ellipsoid_of_inertia.mnemonic: i",
  "Viewmol*_popup.show_ellipsoid_of_inertia.accelerator: Meta<Key>I",
  "Viewmol*_popup.drawing_modes.labelString:        Drawing modes ...",
  "Viewmol*_popup.drawing_modes.mnemonic:           m",
  "Viewmol*_popup.drawing_modes.accelerator:        Meta<Key>M",
  "Viewmol*_popup.background_color.labelString:     Background color ...",
  "Viewmol*_popup.background_color.mnemonic:        B",
  "Viewmol*_popup.background_color.accelerator:     Meta<Key>B",
  "Viewmol*_popup.foreground_color.labelString:     Ground color ...",
  "Viewmol*_popup.foreground_color.mnemonic:        G",
  "Viewmol*_popup.foreground_color.accelerator:     Meta<Key>G",
  "Viewmol*_popup.label_atoms.labelString:          Label atoms",
  "Viewmol*_popup.label_atoms.mnemonic:             L",
  "Viewmol*_popup.label_atoms.accelerator:          Meta<Key>L",
  "Viewmol*_popup.annotate.labelString:             Annotate",
  "Viewmol*_popup.annotate.accelerator:             Ctrl<Key>N",
  "Viewmol*_popup.annotate.acceleratorText:         Ctrl+N",
  "Viewmol*_popup.runScript.labelString:            Run script",
  "Viewmol*select.labelString:                      Select ...",
  "Viewmol*select.accelerator:                      Ctrl<Key>R",
  "Viewmol*select.acceleratorText:                  Ctrl+R",
  "Viewmol*_popup.hardcopy.labelString:             Save drawing ...",
  "Viewmol*_popup.hardcopy.mnemonic:                d",
  "Viewmol*_popup.hardcopy.accelerator:             Meta<Key>D",
  "Viewmol*_popup.raytracing.labelString:           Ray tracing",
  "Viewmol*_popup.raytracing.mnemonic:              R",
  "Viewmol*_popup.raytracing.accelerator:           Meta<Key>R",
  "Viewmol*_popup.manual.labelString:               Help/Manual",
  "Viewmol*_popup.manual.mnemonic:                  H",
  "Viewmol*_popup.manual.accelerator:               Meta<Key>H",
  "Viewmol*_popup.saveConfiguration.labelString:    Configuration ...",
  "Viewmol*_popup.quit.labelString:                 Quit",
  "Viewmol*_popup.quit.mnemonic:                    Q",
  "Viewmol*_popup.quit.accelerator:                 Meta<Key>Q",
  "Viewmol*_popup.select_molecule.labelString:      Select molecule",
  "Viewmol*all.labelString:                         All",
  "Viewmol*spectrumForm_popup.title:                Settings for spectrum",
  "Viewmol.spectrum*_popup.settings_spectrum.labelString: Settings for spectrum ...",
  "Viewmol.spectrum*_popup.settings_spectrum.mnemonic: S",
  "Viewmol.spectrum*_popup.settings_spectrum.accelerator: Meta<Key>S",
  "Viewmol.spectrum*_popup.observed_spectrum.labelString: Read observed spectrum ...",
  "Viewmol.spectrum*_popup.observed_spectrum.mnemonic: R",
  "Viewmol.spectrum*_popup.observed_spectrum.accelerator: Meta<Key>R",
  "Viewmol.spectrum*_popup.delete_spectrum.labelString: Delete observed spectrum ...",
  "Viewmol.spectrum*_popup.delete_spectrum.mnemonic: e",
  "Viewmol.spectrum*_popup.delete_spectrum.accelerator: Meta<Key>E",
  "Viewmol.spectrum*_popup.imaginary_wave_numbers.labelString: Imaginary wave numbers ...",
  "Viewmol.spectrum*_popup.zoom_out.labelString:    Zoom out",
  "Viewmol.spectrum*_popup.zoom_out.mnemonic:       Z",
  "Viewmol.spectrum*_popup.zoom_out.accelerator:    Meta<Key>Z",
  "Viewmol.spectrum*_popup.hardcopy.labelString:    Save drawing ...",
  "Viewmol.spectrum*_popup.hardcopy.mnemonic:       d",
  "Viewmol.spectrum*_popup.hardcopy.accelerator:    Meta<Key>D",
  "Viewmol.spectrum*_popup.foreground_color.labelString: Foreground color ...",
  "Viewmol.spectrum*_popup.foreground_color.mnemonic: F",
  "Viewmol.spectrum*_popup.foreground_color.accelerator: Meta<Key>F",
  "Viewmol.spectrum*_popup.background_color.labelString: Background color ...",
  "Viewmol.spectrum*_popup.background_color.mnemonic: B",
  "Viewmol.spectrum*_popup.background_color.accelerator: Meta<Key>B",
  "Viewmol.spectrum*_popup.quit_spectrum.labelString: Quit spectrum",
  "Viewmol.spectrum*_popup.quit_spectrum.mnemonic:  Q",
  "Viewmol.spectrum*_popup.quit_spectrum.accelerator: Meta<Key>Q",
  "Viewmol*thermoForm_popup.title:                  Thermodynamics",
#ifdef IRIX
  "Viewmol*tabs*fontList:                           -adobe-helvetica-medium-r-normal--14-*=DEFAULT,-adobe-helvetica-medium-r-normal--8-*=INDEX",
  "Viewmol*tabs.TabBookClip*fontList:               -adobe-helvetica-bold-r-normal--14-*=DEFAULT,-adobe-helvetica-bold-r-normal--8-*=INDEX,-adobe-symbol-medium-r-normal--14-*=SYMBOL",
#else
  "Viewmol*tabs*fontList:                           -adobe-helvetica-medium-r-normal--12-120-75-75-p-67-iso8859-1=DEFAULT,-misc-fixed-medium-r-normal--8-80-75-75-c-50-iso8859-1=INDEX",
  "Viewmol*tabs.TabBookClip*fontList:               -adobe-helvetica-medium-r-normal--12-120-75-75-p-67-iso8859-1=DEFAULT,-misc-fixed-medium-r-normal--8-80-75-75-c-50-iso8859-1=INDEX,-adobe-symbol-medium-r-normal--12-120-75-75-p-74-adobe-fontspecific=SYMBOL",
#endif
  "Viewmol*thermoForm*molecules.labelString:        Molecules",
  "Viewmol*thermoForm*reactions.labelString:        Reactions",
  "Viewmol*thermoForm*moleculeMass:                 Mass %.2f g/mol",
  "Viewmol*thermoForm*solidDensity:                 Density %.2f g/cm^3",
  "Viewmol*thermoForm*symmetryNumber:               Symmetry number %d",
  "Viewmol*thermoForm*rotationalConstants:          Rotational constants %.3f %.3f %.3f 1/cm",
  "Viewmol*joules:                                  J",
  "Viewmol*calories:                                cal",
  "Viewmol*format:                                  %.3f",
  "Viewmol*thermoForm*enthalphy.labelString:        H/[k%s/mol]",
  "Viewmol*thermoForm*entropy.labelString:          S/[%s/(mol K)]",
  "Viewmol*thermoForm*gibbsEnergy.labelString:      G/[k%s/mol]",
  "Viewmol*thermoForm*heatCapacity.labelString:     C_v/[%s/(mol K)]",
  "Viewmol*thermoForm*reactant.labelString:         Reactant",
  "Viewmol*thermoForm*notInvolved.labelString:      Not part of reaction",
  "Viewmol*thermoForm*product.labelString:          Product",
  "Viewmol*thermoForm*allReactions.labelString:     All reactions",
  "Viewmol*thermoForm*noReaction:                   No reaction defined.",
  "Viewmol*thermoForm*missingAtoms:                 (No such reaction is possible)",
  "Viewmol*thermoForm*cantBalance:                  (Unable to balance reaction)",
  "Viewmol*thermoForm*inconsistentType:             \"Reactant/Product\" and \"All Reactions\" cannot be mixed.",
  "Viewmol*thermoForm*translation.labelString:      Translation",
  "Viewmol*thermoForm*pv.labelString:               pV",
  "Viewmol*thermoForm*rotation.labelString:         Rotation",
  "Viewmol*thermoForm*vibration.labelString:        Vibration",
  "Viewmol*thermoForm*total.labelString:            Total",
  "Viewmol*thermoForm*electronicEnergy.labelString: Electronic reaction energy",
  "Viewmol*thermoForm*statisticalEnergy.labelString: Statistical mechanical reaction energy",
  "Viewmol*thermoForm*reactionEnergy.labelString:   Total reaction energy",
  "Viewmol*thermoForm*reactionEntropy.labelString:  Reaction entropy",
  "Viewmol*thermoForm*reactionGibbsEnergy.labelString:  Gibbs energy of reaction",
  "Viewmol*thermoForm*reactionHeatCapacity.labelString: Heat capacity of reaction",
  "Viewmol*thermoForm*equilibriumConstant.labelString: Logarithm of equilibrium constant (log K)",
  "Viewmol*thermoForm*previous.labelString:         Previous reaction",
  "Viewmol*thermoForm*next.labelString:             Next reaction",
  "Viewmol*kiloperMole:                             % 15.2f k%s/mol",
  "Viewmol*perMoleandK:                             % 15.2f %s/(mol K)",
  "Viewmol*noUnit:                                  % 15.2f",
  "Viewmol*thermoForm*unitlabel.labelString:        Use", 
  "Viewmol*thermoForm*joules.labelString:           Joules",
  "Viewmol*thermoForm*calories.labelString:         Calories",
  "Viewmol*thermoForm*thermocalories.labelString:   Thermochemical calories",
  "Viewmol*thermoForm*temperature.labelString:      Temperature/[K]", 
  "Viewmol*thermoForm*pressure.labelString:         Pressure/[atm]", 
  "Viewmol*balanceForm_popup.title:                 Balance reaction manually",
#ifdef IRIX
  "Viewmol*balanceForm*fontList:                    -adobe-helvetica-bold-r-normal--14-*=DEFAULT,-adobe-helvetica-bold-r-normal--8-*=INDEX,-adobe-symbol-medium-r-normal--14-*=SYMBOL",
#else
  "Viewmol*balanceForm*fontList:                    -adobe-times-bold-r-normal--14-140-75-75-p-77-iso8859-1=DEFAULT,-adobe-times-bold-r-normal--10-100-75-75-p-57-iso8859-1=INDEX,-adobe-symbol-medium-r-normal--14-140-75-75-p-85-adobe-fontspecific=SYMBOL",
#endif
  "Viewmol*historyForm_popup.title:                 Settings for history",
  "Viewmol.history*_popup.settings_history.labelString: Settings for history ...",
  "Viewmol.history*_popup.settings_history.mnemonic: S",
  "Viewmol.history*_popup.settings_history.accelerator: Meta<Key>S",
  "Viewmol.history*_popup.animate_history.labelString: Animate",
  "Viewmol.history*_popup.animate_history.mnemonic:    A",
  "Viewmol.history*_popup.animate_history.accelerator: Meta<Key>A",
  "Viewmol.history*_popup.hardcopy.labelString:     Save drawing ...",
  "Viewmol.history*_popup.hardcopy.mnemonic:        d",
  "Viewmol.history*_popup.hardcopy.accelerator:     Meta<Key>D",
  "Viewmol.history*_popup.energy_color.labelString: Color for energy...",
  "Viewmol.history*_popup.energy_color.mnemonic:    e",
  "Viewmol.history*_popup.energy_color.accelerator: Meta<Key>E",
  "Viewmol.history*_popup.gradient_color.labelString: Color for gradient...",
  "Viewmol.history*_popup.gradient_color.mnemonic:  g",
  "Viewmol.history*_popup.gradient_color.accelerator: Meta<Key>G",
  "Viewmol.history*_popup.background_color.labelString: Background color ...",
  "Viewmol.history*_popup.background_color.mnemonic: B",
  "Viewmol.history*_popup.background_color.accelerator: Meta<Key>B",
  "Viewmol.history*_popup.quit_history.labelString: Quit optimization history",
  "Viewmol.history*_popup.quit_history.mnemonic:    Q",
  "Viewmol.history*_popup.quit_history.accelerator: Meta<Key>Q",
  "Viewmol.MODiagram*_popup.settings_modiagram.labelString: Settings for energy level diagram ...",
  "Viewmol.MODiagram*_popup.settings_modiagram.mnemonic: S",
  "Viewmol.MODiagram*_popup.settings_modiagram.accelerator: Meta<Key>S",
  "Viewmol.MODiagram*_popup.transition.labelString: Transition",
  "Viewmol.MODiagram*_popup.transition.mnemonic:    T",
  "Viewmol.MODiagram*_popup.transition.accelerator: Meta<Key>T",
  "Viewmol.MODiagram*_popup.zoom_out.labelString:   Zoom out",
  "Viewmol.MODiagram*_popup.zoom_out.mnemonic:      Z",
  "Viewmol.MODiagram*_popup.zoom_out.accelerator:   Meta<Key>Z",
  "Viewmol.MODiagram*_popup.hardcopy.labelString:   Save drawing ...",
  "Viewmol.MODiagram*_popup.hardcopy.mnemonic:      d",
  "Viewmol.MODiagram*_popup.hardcopy.accelerator:   Meta<Key>D",
  "Viewmol.MODiagram*_popup.energy_levels.labelString: Draw density of states",
  "Viewmol.MODiagram*_popup.energy_levels.mnemonic: e",
  "Viewmol.MODiagram*_popup.energy_levels.accelerator: Meta<Key>E",
  "Viewmol.MODiagram*_popup.foreground_color.labelString: Foreground color ...",
  "Viewmol.MODiagram*_popup.foreground_color.mnemonic: F",
  "Viewmol.MODiagram*_popup.foreground_color.accelerator: Meta<Key>F",
  "Viewmol.MODiagram*_popup.background_color.labelString: Background color ...",
  "Viewmol.MODiagram*_popup.background_color.mnemonic: B",
  "Viewmol.MODiagram*_popup.background_color.accelerator: Meta<Key>B",
  "Viewmol.MODiagram*_popup.quit_modiagram.labelString: Quit energy level diagram",
  "Viewmol.MODiagram*_popup.quit_modiagram.mnemonic: Q",
  "Viewmol.MODiagram*_popup.quit_modiagram.accelerator: Meta<Key>Q",
  "Viewmol*messageForm_popup*exit.labelString:      Exit",
  "Viewmol*messageForm_popup*title:                 Note",
  "Viewmol*basisForm_popup.title:                   Basis functions",
  "Viewmol*basisForm_popup.basisForm.rowcolumn.atomname.labelString: Basis functions of atom %s%d",
  "Viewmol*infoForm_popup.title:                    Python",
  "Viewmol.fileSelectionBox_popup.title:            File selection",
  "Viewmol*fileSelectionBox.dirListLabelString:     Directories",
  "Viewmol*fileSelectionBox.fileListLabelString:    Files",
  "Viewmol*fileSelectionBox.filterLabelString:      Path",
  "Viewmol*fileSelectionBox.applyLabelString:       Filter",
  "Viewmol*fileSelectionBox.okLabelString:          OK",
  "Viewmol*fileSelectionBox.cancelLabelString:      Cancel",
  "Viewmol*fileSelectionBox.selectionLabelString:   Selection",
  "Viewmol*ok.labelString:                          OK",
  "Viewmol*cancel.labelString:                      Cancel",
  "Viewmol*continue.labelString:                    Continue",
  "Viewmol*save.labelString:                        Save",
  "Viewmol*optimizationForm_popup*title:            Optimization history",
  "Viewmol*optimizationForm*energies.labelString:   Energies",
  "Viewmol*optimizationForm*norms.labelString:      Gradient norm",
  "Viewmol*optimizationForm*scales.labelString:     Scales",
  "Viewmol*spectrumForm*all_modes.labelString:      All modes",
  "Viewmol*spectrumForm*ir_modes.labelString:       IR active modes",
  "Viewmol*spectrumForm*raman_modes.labelString:    Raman active modes",
  "Viewmol*spectrumForm*ins_modes.labelString:      Inelastic neutron scattering",
  "Viewmol*spectrumForm*animate.labelString:        Animate",
  "Viewmol*spectrumForm*draw_arrows.labelString:    Draw arrows",
  "Viewmol*spectrumForm*distort.labelString:        Distort",
  "Viewmol*spectrumForm*line_spectrum.labelString:  Line spectrum",
  "Viewmol*spectrumForm*gaussian_spectrum.labelString: Gaussian spectrum",
  "Viewmol*spectrumForm*setins.labelString:         Set weights for inelastic neutron scattering",
  "Viewmol*spectrumForm*axisTop.labelString:        Wave numbers shown on top",
  "Viewmol*spectrumForm*showGrid.labelString:       Show grid",
  "Viewmol*spectrumForm*lineWidthLabel.labelString: Line width",
  "Viewmol*spectrumForm*temperature.labelString:    Temperature",
  "Viewmol*spectrumForm*amplitude.labelString:      Amplitude",
  "Viewmol*spectrumForm*scale.labelString:          Scale wave\\nnumbers",
  "Viewmol*wavefunctionForm_popup.title:            Wave function",
  "Viewmol*wavefunctionForm*all_off.labelString:    All off",
  "Viewmol*wavefunctionForm*basis_function.labelString: Basis function",
  "Viewmol*wavefunctionForm*basis_in_mo.labelString: Basis function in MO",
  "Viewmol*wavefunctionForm*molecular_orbital.labelString: Molecular orbital",
  "Viewmol*wavefunctionForm*electron_density.labelString: Electron density",
  "Viewmol*wavefunctionForm*interpolationLabel.labelString: Interpolation",
  "Viewmol*wavefunctionForm*none.labelString:       None",
  "Viewmol*wavefunctionForm*linear.labelString:     Linear",
  "Viewmol*wavefunctionForm*logarithmic.labelString: Logarithmic",
  "Viewmol*wavefunctionForm*levelLabel.labelString: Isosurface",
  "Viewmol*wavefunctionForm*gridLabel.labelString:  Resolution of grid",
  "Viewmol*wavefunctionForm*automatic.labelString:  Automatic recalculation",
  "Viewmol*MODiagramForm_popup.title:               Settings",
  "Viewmol*MODiagramForm*hartrees.labelString:      Hartrees",
  "Viewmol*MODiagramForm*kj_mol.labelString:        kJ/mol",
  "Viewmol*MODiagramForm*ev.labelString:            eV",
  "Viewmol*MODiagramForm*cm.labelString:            cm^-1",
  "Viewmol*MODiagramForm*resolutionlabel.labelString: Resolution",
  "Viewmol*printForm_popup.title:                   Save Drawing",
  "Viewmol*printForm*hpgl.labelString:              HPGL",
  "Viewmol*printForm*postscript.labelString:        PostScript",
  "Viewmol*printForm*raytracer.labelString:         Povray",
  "Viewmol*printForm*tiff.labelString:              TIFF",
  "Viewmol*printForm*png.labelString:               PNG",
  "Viewmol*printForm*landscape.labelString:         Landscape",
  "Viewmol*printForm*portrait.labelString:          Portrait",
  "Viewmol*printForm*papersize.labelString:         Paper size",
  "Viewmol*printForm*a5.labelString:                A5",
  "Viewmol*printForm*a4.labelString:                A4",
  "Viewmol*printForm*a3.labelString:                A3",
  "Viewmol*printForm*letter.labelString:            Letter",
  "Viewmol*printForm*legal.labelString:             Legal",
  "Viewmol*printForm*userdefined.labelString:       User defined",
  "Viewmol*printForm*lzw.labelString:               LZW",
  "Viewmol*printForm*mac.labelString:               Macintosh",
  "Viewmol*printForm*none.labelString:              None",
  "Viewmol*printForm*compressionlabel.labelString:  TIFF compression",
  "Viewmol*printForm*transparent.labelString:       Background transparent",
  "Viewmol*printForm*widthlabel.labelString:        Paper width in mm",
  "Viewmol*printForm*heightlabel.labelString:       Paper height in mm",
  "Viewmol*printForm*file.labelString:              File",
  "Viewmol*printForm*select.labelString:            Select",
  "Viewmol*drawingModeForm_popup.title:             Drawing Modes",
  "Viewmol*drawingModeForm*dots.labelString:        with dots",
  "Viewmol*drawingModeForm*lines.labelString:       with lines",
  "Viewmol*drawingModeForm*surfaces.labelString:    with surface",
  "Viewmol*drawingModeForm*simplify.labelString:    Lines while rotating",
  "Viewmol*drawingModeForm*onOffLabel.labelString:  Lights on/off",
  "Viewmol*drawingModeForm*molecule.labelString:    Move molecule",
  "Viewmol*drawingModeForm*viewpoint.labelString:   Move view point",
  "Viewmol*drawingModeForm*light0.labelString:      Move light 1",
  "Viewmol*drawingModeForm*light1.labelString:      Move light 2",
  "Viewmol*drawingModeForm*projectionLabel.labelString: Projection",
  "Viewmol*drawingModeForm*orthographic.labelString: Orthographic",
  "Viewmol*drawingModeForm*perspective.labelString: Perspective",
  "Viewmol*drawingModeForm*light0OnOff.labelString: Light 1",
  "Viewmol*drawingModeForm*light1OnOff.labelString: Light 2",
  "Viewmol*drawingModeForm*sphereResolutionLabel.labelString: Resolution of spheres",
  "Viewmol*drawingModeForm*lineWidthLabel.labelString: Line width",
  "Viewmol*colorEditor_popup.title:                 Color Editor",
  "Viewmol*colorEditor*smoothRed.labelString:       Smooth",
  "Viewmol*colorEditor*smoothGreen.labelString:     Smooth",
  "Viewmol*colorEditor*smoothBlue.labelString:      Smooth",
  "Viewmol*doRaytracing.labelString:                Start raytracing",
  "Viewmol*stopRaytracing.labelString:              Don't start raytracing",
  "Viewmol*saveMoleculeForm_popup*title:            Save molecule",
  "Viewmol*saveMoleculeForm*car.labelString:        MSI car-file",
  "Viewmol*saveMoleculeForm*arc.labelString:        MSI arc-file",
  "Viewmol*saveMoleculeForm*gauss.labelString:      Gaussian 98 input file",
  "Viewmol*saveMoleculeForm*mol.labelString:        MDL mol-file",
  "Viewmol*saveMoleculeForm*tm.labelString:         Turbomole file",
  "Viewmol*unitcellForm_popup.title:                Unit cell",
  "Viewmol*unitcellForm*visible.labelString:        visible",
  "Viewmol*unitcellForm*avalue.titleString:         a",
  "Viewmol*unitcellForm*bvalue.titleString:         b",
  "Viewmol*unitcellForm*cvalue.titleString:         c",
  "Viewmol*unitcellForm*miller.labelString:         Show Miller plane",
  "Viewmol*unitcellForm*hvalue.titleString:         h",
  "Viewmol*unitcellForm*kvalue.titleString:         k",
  "Viewmol*unitcellForm*lvalue.titleString:         l",
  "Viewmol*configurationForm_popup*title:           Configuration",
  "Viewmol*configurationForm*en_US.labelString:     English",
  "Viewmol*configurationForm*fr.labelString:        French",
  "Viewmol*configurationForm*de.labelString:        German",
  "Viewmol*configurationForm*hu.labelString:        Hungarian",
  "Viewmol*configurationForm*pl.labelString:        Polish",
  "Viewmol*configurationForm*ru.labelString:        Russian",
  "Viewmol*configurationForm*es.labelString:        Spanish",
  "Viewmol*configurationForm*tr.labelString:        Turkish",
  "Viewmol*configurationForm*browserLabel.labelString: Location of Web browser",
  "Viewmol*configurationForm*molochLabel.labelString:    Location of Moloch",
  "Viewmol*configurationForm*raytracerLabel.labelString:  Location of Povray",
  "Viewmol*configurationForm*displayImageLabel.labelString:  Location of display program for images",
  "Viewmol.unknownParameter:                        Unknown command line parameter: %s",
  "Viewmol.selectFormat:                            Please select format.",
  "Viewmol.selectCompression:                       Please select compression method.",
  "Viewmol.TIFFSaved:                               Drawing saved to TIFF file %s.",
  "Viewmol.PNGSaved:                                Drawing saved to PNG file %s.",
  "Viewmol.HPGLSaved:                               Drawing saved to HPGL file %s.",
  "Viewmol.PostscriptSaved:                         Drawing saved to Postscript file %s.",
  "Viewmol.RaytracerSaved:                          Drawing saved to Rayshade file %s.",
  "Viewmol.MoleculeSaved:                           Molecule saved to file %s.",
  "Viewmol.ConfigurationSaved:                      Configuration saved to file $HOME/.Xdefaults.",
  "Viewmol.noControlFile:                           There is no control file in the current directory.",
  "Viewmol.unableToOpen:                            Unable to open file %s.",
  "Viewmol.molochFailed:                            Moloch failed.",
  "Viewmol.noMolochOutput:                          Moloch output does not exist.",
  "Viewmol.errorOnLine:                             Error on line %d of %s.",
  "Viewmol.noColors:                                Unable to allocate sufficient number of colors.",
  "Viewmol.noInputFilter:                           No input filter specified in %s.",
  "Viewmol.noDefaultFilter:                         No default input filter found.",
  "Viewmol.noFile:                                  File %s not found.",
  "Viewmol.cannotOpen:                              Unable to open file %s.",
  "Viewmol.FileExists:                              File %s already exists.",
  "Viewmol.cannotExecute:                           Cannot execute: %s.",
  "Viewmol.notConverged:                            MOs in %s are not converged.",
  "Viewmol.noBrowser:                               Cannot find Web browser for the manual.\\n%s does not exist. Put a line\\n'Viewmol.webBrowser: <your Web browser>'\\ninto your $HOME/.Xdefaults file.",
  "Viewmol.noManual:                                Manual file %s\\ndoes not exist.",
  "Viewmol.cannotDisplay:                           Unable to display manual.\nWeb browser does not start.",
  "Viewmol.noVisual:                                Unable to find a window suitable for OpenGL drawing.\\nThere might be an installation problem with OpenGL\\nor the X server has not been started with the\\ncorrect extensions.",
  "Viewmol.noRayshade:                              No location for Rayshade specified in resources.",
  "Viewmol.noDisplay:                               No display program for images specified in resources.",
  "Viewmol.unableToWriteFeedback:                   Cannot allocate enough memory to write drawing to file.",
  "Viewmol.wavenumberTitle:                         %s mode, %.6g cm-1",
  "Viewmol.selectAtomTitle:                         Please select atom by clicking on it.",
  "Viewmol.selectINSTitle:                          Click on atom to set INS weight to %f.",
  "Viewmol.basisfunctionTitle:                      Basis function %d: %s%d %s",
  "Viewmol.basisfunctionInMOTitle:                  Basis function %d in MO %d: %s%d %.7f*%s",
  "Viewmol.molecularOrbitalTitle:                   Molecular orbital %d: %s, energy %f Hartree",
  "Viewmol.electronDensityTitle:                    Electron density",
  "Viewmol.isosurfaceLabel:                         isosurface: ",
  "Viewmol.isosurfaceLevel:                         %.3f ",
  "Viewmol.historyTitle:                            Cycle %d Energy %18.10f Hartree, |dE/dxyz| %10.6f",
  "Viewmol.wavenumber:                              Wave numbers (cm**-1)",
  "Viewmol.intensity:                               Intensity (%)",
  "Viewmol.energy:                                  Energy",
  "Viewmol.gradientNorm:                            Gradient norm",
  "Viewmol.animateSave:                             You cannot plot an animated molecule.",
  "Viewmol.noNormalModes:                           Normal modes have not been read in.",
  "Viewmol.GaussianProblem:                         The Gaussian output contains %c functions.\\nThis combination is currently not supported.",
  "Viewmol.unknownResource:                         The value %s is not allowed for\\nthe resource %s.",
  "Viewmol.unsupportedVersion:                      Files of version %s are not supported.",
  "Viewmol.wrongFiletype:                           File %s is of wrong file type.",
  "Viewmol.wrongReference:                          File referenced in %s as 'type=car' is of wrong file type.",
  "Viewmol.onlySymmetricBasis:                      Input file contains basis sets only for non-symmetry\\nequivalent atoms. Assuming that the basis set is the\\nsame for all atoms of the same element.",
  "Viewmol.unknownErrorMessage:                     Input filter sent unknown error message:\\n%s.",
  "Viewmol.noCoordinates:                           Cannot find coordinates in file %s.",
  "Viewmol.noEnergy:                                Cannot find energy in file %s.",
  "Viewmol.noMOselected:                            There is no MO selected for %s.\\nPlease select a MO in the energy level\\ndiagram, then try again.",
  "Viewmol.notChangeable:                           This coordinate cannot be changed\\nsince it is part of a ring.",
  "Viewmol.notDefined:                              This internal coordinate is not defined.",
  "Viewmol.formatNotRecognized:                     Cannot recognize format of file %s.",
  "Viewmol.wrongBrowser:                            Web browser cannot be found at specified location.",
  "Viewmol.wrongMoloch:                             Moloch cannot be found at specified location.",
  "Viewmol.differentMolecules:                      Internal coordinates cannot be measured between different molecules.",
  "Viewmol.BusError:                                A bus error occured. Viewmol\\ncannot continue.",
  "Viewmol.FloatingPointException:                  A floating exception occured.\\nViewmol cannot continue.",
  "Viewmol.SegmentationViolation:                   A segmentation fault occured.\\nViewmol cannot continue.",
  "Viewmol.deleteAll:                               Do you really want to delete\\nall molecules ?",
  "Viewmol.deleteOne:                               Do you really want to delete\\n%s ?",
  "Viewmol.unknownElement:                          Element %s is not known.",
  "Viewmol.unknownElements:                         Elements %s are not known.",
  "Viewmol.missingBasisset:                         The basis set for the atom(s) %s has not been specified.",
  "Viewmol.elementMenuPrefix:                       ",
  "Viewmol.wrongPNGversion:                         Version %s of the PNG library is not supported. At least version 1.4 is needed.",
  NULL
};
